      SUBROUTINE ZLPOP2 (LUN, FILNAM, IERR)
C-----------------------------------------------------------------------
C! open a line-printer text file - actual OPEN call
C# Z2 Printer
C-----------------------------------------------------------------------
C;  Copyright (C) 1995
C;  Associated Universities, Inc. Washington DC, USA.
C;
C;  This program is free software; you can redistribute it and/or
C;  modify it under the terms of the GNU General Public License as
C;  published by the Free Software Foundation; either version 2 of
C;  the License, or (at your option) any later version.
C;
C;  This program is distributed in the hope that it will be useful,
C;  but WITHOUT ANY WARRANTY; without even the implied warranty of
C;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C;  GNU General Public License for more details.
C;
C;  You should have received a copy of the GNU General Public
C;  License along with this program; if not, write to the Free
C;  Software Foundation, Inc., 675 Massachusetts Ave, Cambridge,
C;  MA 02139, USA.
C;
C;  Correspondence concerning AIPS should be addressed as follows:
C;         Internet email: aipsmail@nrao.edu.
C;         Postal address: AIPS Project Office
C;                         National Radio Astronomy Observatory
C;                         520 Edgemont Road
C;                         Charlottesville, VA 22903-2475 USA
C-----------------------------------------------------------------------
C-----------------------------------------------------------------------
C   open a line-printer text file - the actual machine-dependent OPEN
C   call in Fortran or whatever
C   Input:
C      LUN      I       LUN to use
C      FILNAM   C*(*)   output file name
C   Output:
C      IERR     I       error status returned by system
C   VMS version.
C-----------------------------------------------------------------------
      CHARACTER FILNAM*(*)
      INTEGER   LUN, IERR
C-----------------------------------------------------------------------
C                                       Fortran generic call
      OPEN (UNIT=LUN, STATUS='NEW', FILE=FILNAM, IOSTAT=IERR,
     *   CARRIAGECONTROL='FORTRAN', DISP='DELETE')
C
 999  RETURN
      END
